#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-9z7lqL4zR6A3xSdlAIslDl
key:                  dhall-1.42.3-9z7lqL4zR6A3xSdlAIslDl
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  2cfee920cf2a7c54ea510cde39b347f6
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-9z7lqL4zR6A3xSdlAIslDl
depends:
    Diff-1.0-2yeHn0RwQ8bEUz2Oy0D0Hq
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf
    aeson-pretty-0.8.11-EabMHmkTJz75BjM34GBJJN
    ansi-terminal-1.1-3WEwGthe7is1LBGeoKnQZb
    atomic-write-0.2.1.1-44S0nFG5sBeIvOkFmKE8eD base-4.18.2.1
    base16-bytestring-1.0.2.0-BOZQoJvp04k6zWThJ612WV
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Ewy0DH0xZp6BX0SdeD8DKD
    cborg-0.2.10.0-K62iK03Z7qT75EPaw7lrIr
    cborg-json-0.2.6.0-A1eHUEn4cZsL1TVycRxN98 containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-8hsqLFf9gbv5TnTFsUmT7P
    data-fix-0.3.4-KvoisZ0kIM0LAmzhtgZfz1 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-An5ds5OCaUP6UEStud2wBg exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-8zGjLtgJopXK62QmSk9di0
    hashable-1.4.7.0-KEzkDU36XICA02zRvxfUEu haskeline-0.8.2.1
    http-client-0.7.19-34xXemB7zi7LDrAIS2UIas
    http-client-tls-0.3.6.4-ADnxKMmkuxZIenWWL3GTLT
    http-types-0.12.4-EqZKGcmXGQgIrxcsE0a1PI
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    megaparsec-9.7.1-33tUprDdwFBJhkf3Oz7GVI
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-GeBMcWFtBsy42rTUiQRkD3
    optparse-applicative-0.18.1.0-1bx6NtkYgnV6peHQkP2ZMq
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-3x38LMQOHjfHcG363ej5bX
    pretty-simple-4.1.4.0-LpqSFDHF8aBFhScAiloVnp
    prettyprinter-1.7.2-APthOzNRqmxChDP01Z5Cem
    prettyprinter-ansi-terminal-1.1.4-GwKMc7d2mkH3sDcpoee7Qa
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-FfOn8C5pQ5M9kVwKQotP6m
    serialise-0.2.6.1-39mDBpnfNeoAQ6GzXkgpGU template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-3Toga9dvTwcIrjaZRxMikb
    text-short-0.1.6.1-DgeisEVco3TG10bZKakjWZ
    th-lift-instances-0.1.20-KXWx4aAycUHDTSCTBLr4s time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-4KMmZ8RUI6D4jdDWnXDUAz
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

